/* Copyright 2017 R. Thomas
 * Copyright 2017 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef C_LIEF_PE_ENUM_TO_STRING_H_
#define C_LIEF_PE_ENUM_TO_STRING_H_

#include "LIEF/visibility.h"

#include "LIEF/PE/enums.h"

#ifdef __cplusplus
extern "C" {
#endif


LIEF_API const char* PE_TYPES_to_string(enum LIEF_PE_PE_TYPES e);
LIEF_API const char* MACHINE_TYPES_to_string(enum LIEF_PE_MACHINE_TYPES e);
LIEF_API const char* SUBSYSTEM_to_string(enum LIEF_PE_SUBSYSTEM e);

#ifdef __cplusplus
}
#endif


#endif
